@@ -41,15 +41,12 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <glib/gprintf.h>
-#include <gio/giomodule.h>
+#include <gio/gio.h>
 
-#include <gio/gvfs.h>
-#include <gio/gurifuncs.h>
-#include <gio/gseekable.h>
-#include <gio/gioerror.h>
-#include <gio/gvolumemonitor.h>
+#include <glib/gurifuncs.h>
 
 /* stuff from common/ */
+#include <gdaemonmount.h>
 #include <gvfsdaemonprotocol.h>
 #include <gdbusutils.h>
 
@@ -200,6 +197,7 @@ file_handle_new (void)
 static void
 file_handle_close_stream (FileHandle *file_handle)
 {
+  debug_print ("file_handle_close_stream\n");
   if (file_handle->stream)
     {
       switch (file_handle->op)
@@ -289,7 +287,7 @@ free_file_handle_for_path (const gchar *path)
   if (fh)
     {
       g_static_mutex_lock (&global_mutex);
-      g_hash_table_remove (global_fh_table, fh);
+      g_hash_table_remove (global_fh_table, path);
       g_static_mutex_unlock (&global_mutex);
       return TRUE;
     }
@@ -298,15 +296,20 @@ free_file_handle_for_path (const gchar *path)
 }
 
 static MountRecord *
-mount_record_new (GVolume *volume)
+mount_record_new (GMount *mount)
 {
   MountRecord *mount_record;
   char *name;
 
   mount_record = g_new (MountRecord, 1);
   
-  mount_record->root = g_volume_get_root (volume);
-  name = g_volume_get_name (volume);
+  mount_record->root = g_mount_get_root (mount);
+  name = g_object_get_data (G_OBJECT (mount), "g-stable-name");
+  if (name != NULL)
+    name = g_strdup (name);
+  else
+    name = g_mount_get_name (mount);
+
   /* Keep in sync with gvfs daemon mount tracker */
   mount_record->name = g_uri_escape_string (name, "+@#$., ", TRUE);
   g_free (name);
@@ -344,15 +347,15 @@ mount_list_free (void)
 }
 
 static gboolean
-mount_record_for_volume_exists (GVolume *volume)
+mount_record_for_mount_exists (GMount *mount)
 {
   GList *l;
   GFile *root;
   gboolean res;
 
-  g_assert (volume != NULL);
+  g_assert (mount != NULL);
 
-  root = g_volume_get_root (volume);
+  root = g_mount_get_root (mount);
 
   res = FALSE;
   
@@ -407,26 +410,26 @@ mount_record_find_root_by_mount_name (const gchar *mount_name)
 static void
 mount_list_update (void)
 {
-  GList *volumes;
+  GList *mounts;
   GList *l;
 
-  volumes = g_volume_monitor_get_mounted_volumes (volume_monitor);
+  mounts = g_volume_monitor_get_mounts (volume_monitor);
 
-  for (l = volumes; l != NULL; l = l->next)
+  for (l = mounts; l != NULL; l = l->next)
     {
-      GVolume *volume = l->data;
+      GMount *mount = l->data;
 
-      if (!mount_record_for_volume_exists (volume))
+      if (!mount_record_for_mount_exists (mount))
         {
           mount_list_lock ();
-          mount_list = g_list_prepend (mount_list, mount_record_new (volume));
+          mount_list = g_list_prepend (mount_list, mount_record_new (mount));
           mount_list_unlock ();
         }
       
-      g_object_unref (volume);
+      g_object_unref (mount);
     }
   
-  g_list_free (volumes);
+  g_list_free (mounts);
 }
 
 #if 0
@@ -590,10 +593,10 @@ vfs_statfs (const gchar *path, struct statvfs *stbuf)
           stbuf->f_flag = 0;  /* Ignored by FUSE */
           stbuf->f_namemax = 1024;
 
-          if (g_file_info_has_attribute (file_info, G_FILE_ATTRIBUTE_FS_SIZE))
-            stbuf->f_blocks = g_file_info_get_attribute_uint64 (file_info, G_FILE_ATTRIBUTE_FS_SIZE) / 4096;
-          if (g_file_info_has_attribute (file_info, G_FILE_ATTRIBUTE_FS_FREE))
-            stbuf->f_bfree = stbuf->f_bavail = g_file_info_get_attribute_uint64 (file_info, G_FILE_ATTRIBUTE_FS_FREE) / 4096;
+          if (g_file_info_has_attribute (file_info, G_FILE_ATTRIBUTE_FILESYSTEM_SIZE))
+            stbuf->f_blocks = g_file_info_get_attribute_uint64 (file_info, G_FILE_ATTRIBUTE_FILESYSTEM_SIZE) / 4096;
+          if (g_file_info_has_attribute (file_info, G_FILE_ATTRIBUTE_FILESYSTEM_FREE))
+            stbuf->f_bfree = stbuf->f_bavail = g_file_info_get_attribute_uint64 (file_info, G_FILE_ATTRIBUTE_FILESYSTEM_FREE) / 4096;
         }
       else if (error)
         {
@@ -1356,7 +1359,7 @@ readdir_for_file (GFile *base_file, gpointer buf, fuse_fill_dir_t filler)
 
   g_assert (base_file != NULL);
 
-  enumerator = g_file_enumerate_children (base_file, G_FILE_ATTRIBUTE_STD_NAME, 0, NULL, &error);
+  enumerator = g_file_enumerate_children (base_file, G_FILE_ATTRIBUTE_STANDARD_NAME, 0, NULL, &error);
   if (!enumerator)
     {
       gint result;
@@ -1859,7 +1862,6 @@ vfs_utimens (const gchar *path, const struct timespec tv [2])
 
   if (file)
     {
-      GFileAttributeValue attr_value = G_FILE_ATTRIBUTE_VALUE_INIT;
       guint64 atime;
       guint64 mtime;
 
@@ -1877,15 +1879,15 @@ vfs_utimens (const gchar *path, const struct timespec tv [2])
           mtime = atime;
         }
 
-      attr_value.type = G_FILE_ATTRIBUTE_TYPE_UINT64;
-
-      attr_value.u.uint64 = atime;
-      g_file_set_attribute (file, G_FILE_ATTRIBUTE_TIME_ACCESS_USEC, &attr_value, 0, NULL, &error);
+      g_file_set_attribute (file, G_FILE_ATTRIBUTE_TIME_ACCESS_USEC,
+                            G_FILE_ATTRIBUTE_TYPE_UINT64, &atime,
+                            0, NULL, &error);
 
       if (!error)
         {
-          attr_value.u.uint64 = mtime;
-          g_file_set_attribute (file, G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC, &attr_value, 0, NULL, &error);
+          g_file_set_attribute (file, G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC,
+                                G_FILE_ATTRIBUTE_TYPE_UINT64, &mtime,
+                                0, NULL, &error);
         }
 
       if (error)
@@ -1936,14 +1938,14 @@ vfs_chmod (const gchar *path, mode_t mode)
 
 static void
 mount_tracker_mounted_cb (GVolumeMonitor *volume_monitor,
-                          GVolume        *volume)
+                          GMount         *mount)
 {
   MountRecord *mount_record;
 
-  if (mount_record_for_volume_exists (volume))
+  if (mount_record_for_mount_exists (mount))
     return;
 
-  mount_record = mount_record_new (volume);
+  mount_record = mount_record_new (mount);
 
   mount_list_lock ();
   mount_list = g_list_prepend (mount_list, mount_record);
@@ -1952,16 +1954,16 @@ mount_tracker_mounted_cb (GVolumeMonitor *volume_monitor,
 
 static void
 mount_tracker_unmounted_cb (GVolumeMonitor *volume_monitor,
-                            GVolume        *volume)
+                            GMount         *mount)
 {
   GFile *root;
   GList *l;
 
-  root = g_volume_get_root (volume);
+  root = g_mount_get_root (mount);
   
   mount_list_lock ();
   
-  root = g_volume_get_root (volume);
+  root = g_mount_get_root (mount);
 
   for (l = mount_list; l != NULL; l = l->next)
     {
@@ -1986,8 +1988,8 @@ subthread_main (gpointer data)
   
   mount_list_update ();
   
-  g_signal_connect (volume_monitor, "volume_mounted", (GCallback) mount_tracker_mounted_cb, NULL);
-  g_signal_connect (volume_monitor, "volume_unmounted", (GCallback) mount_tracker_unmounted_cb, NULL);
+  g_signal_connect (volume_monitor, "mount_added", (GCallback) mount_tracker_mounted_cb, NULL);
+  g_signal_connect (volume_monitor, "mount_removed", (GCallback) mount_tracker_unmounted_cb, NULL);
 
   g_main_loop_run (subthread_main_loop);
 
@@ -2040,7 +2042,6 @@ vfs_init (struct fuse_conn_info *conn)
 	DBusConnection *dbus_conn;
   DBusMessage *message;
 	DBusError error;
-  GVfs *vfs;
   
   daemon_creation_time = time (NULL);
   daemon_uid = getuid ();
